import React from 'react';
import { DeployingResource, TerraformPlan, TerraformOutput } from "./models/terraform";
export declare enum Status {
    STARTING = "starting",
    SYNTHESIZING = "synthesizing",
    SYNTHESIZED = "synthesized",
    INITIALIZING = "initializing",
    PLANNING = "planning",
    PLANNED = "planned",
    DEPLOYING = "deploying",
    DESTROYING = "destroying",
    DONE = "done"
}
export declare type DeployState = {
    status: Status;
    resources: DeployingResource[];
    plan?: TerraformPlan;
    stackName?: string;
    stackJSON?: string;
    errors?: string[];
    output?: {
        [key: string]: TerraformOutput;
    };
};
interface TerraformProviderConfig {
    initialState?: DeployState;
}
export declare const TerraformProvider: React.FunctionComponent<TerraformProviderConfig>;
interface UseTerraformInput {
    targetDir: string;
    synthCommand: string;
}
export declare const useTerraformState: () => DeployState;
export declare const useTerraform: ({ targetDir, synthCommand }: UseTerraformInput) => {
    synth: () => DeployState;
    init: () => DeployState;
    plan: () => DeployState;
    planDestroy: () => DeployState;
    deploy: (plan?: TerraformPlan | undefined) => DeployState;
    destroy: (plan?: TerraformPlan | undefined) => DeployState;
};
export {};
